@@ -14,14 +14,12 @@ public class Driver {
 
 		// FIXME: Error checking is non-existant here...
 
-		string home_directory = Environment.GetEnvironmentVariable ("HOME");
-		Directory.SetCurrentDirectory (home_directory);
-
-		string base_directory = home_directory + "/.gnome2/f-spot";
+		string home_directory = FSpot.Global.HomeDirectory;
+		string base_directory = FSpot.Global.BaseDirectory;
 		if (! File.Exists (base_directory))
 			Directory.CreateDirectory (base_directory);
 
-		Db db = new Db (base_directory + "/photos.db", true);
+		Db db = new Db (Path.Combine (base_directory, "photos.db"), true);
 		
 		Gtk.Window.DefaultIconList = new Gdk.Pixbuf [] {PixbufUtils.LoadFromAssembly ("f-spot-camera.png")};
 
